# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepGeom module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepgeom.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepGeom
else:
    import _RWStepGeom

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepGeom.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepGeom.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepGeom.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepGeom.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepGeom.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepGeom.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepGeom.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepGeom.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepGeom.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepGeom.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepGeom.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepGeom.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepGeom.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepGeom.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepGeom.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepGeom.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepGeom.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepGeom:
_RWStepGeom.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepGeom.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepGeom
import OCC.Core.StepRepr
import OCC.Core.StepBasic

from enum import IntEnum
from OCC.Core.Exception import *



class RWStepGeom_RWAxis1Placement(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWAxis1Placement_swiginit(self, _RWStepGeom.new_RWStepGeom_RWAxis1Placement(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Axis1Placement

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWAxis1Placement_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Axis1Placement
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWAxis1Placement_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Axis1Placement

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWAxis1Placement_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWAxis1Placement

# Register RWStepGeom_RWAxis1Placement in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWAxis1Placement_swigregister(RWStepGeom_RWAxis1Placement)

class RWStepGeom_RWAxis2Placement2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWAxis2Placement2d_swiginit(self, _RWStepGeom.new_RWStepGeom_RWAxis2Placement2d(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Axis2Placement2d

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWAxis2Placement2d_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Axis2Placement2d
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWAxis2Placement2d_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Axis2Placement2d

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWAxis2Placement2d_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWAxis2Placement2d

# Register RWStepGeom_RWAxis2Placement2d in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWAxis2Placement2d_swigregister(RWStepGeom_RWAxis2Placement2d)

class RWStepGeom_RWAxis2Placement3d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWAxis2Placement3d_swiginit(self, _RWStepGeom.new_RWStepGeom_RWAxis2Placement3d(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Axis2Placement3d

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWAxis2Placement3d_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Axis2Placement3d
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWAxis2Placement3d_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Axis2Placement3d

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWAxis2Placement3d_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWAxis2Placement3d

# Register RWStepGeom_RWAxis2Placement3d in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWAxis2Placement3d_swigregister(RWStepGeom_RWAxis2Placement3d)

class RWStepGeom_RWBSplineCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBSplineCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBSplineCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBSplineCurve

# Register RWStepGeom_RWBSplineCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBSplineCurve_swigregister(RWStepGeom_RWBSplineCurve)

class RWStepGeom_RWBSplineCurveWithKnots(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnots_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBSplineCurveWithKnots(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineCurveWithKnots
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnots_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BSplineCurveWithKnots

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnots_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineCurveWithKnots
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnots_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BSplineCurveWithKnots

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnots_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBSplineCurveWithKnots

# Register RWStepGeom_RWBSplineCurveWithKnots in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBSplineCurveWithKnots_swigregister(RWStepGeom_RWBSplineCurveWithKnots)

class RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve

# Register RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve_swigregister(RWStepGeom_RWBSplineCurveWithKnotsAndRationalBSplineCurve)

class RWStepGeom_RWBSplineSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBSplineSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBSplineSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBSplineSurface

# Register RWStepGeom_RWBSplineSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBSplineSurface_swigregister(RWStepGeom_RWBSplineSurface)

class RWStepGeom_RWBSplineSurfaceWithKnots(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnots_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBSplineSurfaceWithKnots(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineSurfaceWithKnots
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnots_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BSplineSurfaceWithKnots

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnots_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineSurfaceWithKnots
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnots_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BSplineSurfaceWithKnots

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnots_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBSplineSurfaceWithKnots

# Register RWStepGeom_RWBSplineSurfaceWithKnots in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnots_swigregister(RWStepGeom_RWBSplineSurfaceWithKnots)

class RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface

# Register RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface_swigregister(RWStepGeom_RWBSplineSurfaceWithKnotsAndRationalBSplineSurface)

class RWStepGeom_RWBezierCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBezierCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBezierCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BezierCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BezierCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BezierCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBezierCurve

# Register RWStepGeom_RWBezierCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBezierCurve_swigregister(RWStepGeom_RWBezierCurve)

class RWStepGeom_RWBezierCurveAndRationalBSplineCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBezierCurveAndRationalBSplineCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBezierCurveAndRationalBSplineCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BezierCurveAndRationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierCurveAndRationalBSplineCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BezierCurveAndRationalBSplineCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierCurveAndRationalBSplineCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BezierCurveAndRationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierCurveAndRationalBSplineCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBezierCurveAndRationalBSplineCurve

# Register RWStepGeom_RWBezierCurveAndRationalBSplineCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBezierCurveAndRationalBSplineCurve_swigregister(RWStepGeom_RWBezierCurveAndRationalBSplineCurve)

class RWStepGeom_RWBezierSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBezierSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBezierSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BezierSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BezierSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BezierSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBezierSurface

# Register RWStepGeom_RWBezierSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBezierSurface_swigregister(RWStepGeom_RWBezierSurface)

class RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BezierSurfaceAndRationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BezierSurfaceAndRationalBSplineSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BezierSurfaceAndRationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface

# Register RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface_swigregister(RWStepGeom_RWBezierSurfaceAndRationalBSplineSurface)

class RWStepGeom_RWBoundaryCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBoundaryCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBoundaryCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BoundaryCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBoundaryCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_BoundaryCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBoundaryCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BoundaryCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBoundaryCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBoundaryCurve

# Register RWStepGeom_RWBoundaryCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBoundaryCurve_swigregister(RWStepGeom_RWBoundaryCurve)

class RWStepGeom_RWBoundedCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBoundedCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBoundedCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BoundedCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBoundedCurve_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BoundedCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBoundedCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBoundedCurve

# Register RWStepGeom_RWBoundedCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBoundedCurve_swigregister(RWStepGeom_RWBoundedCurve)

class RWStepGeom_RWBoundedSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWBoundedSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWBoundedSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_BoundedSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBoundedSurface_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_BoundedSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWBoundedSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWBoundedSurface

# Register RWStepGeom_RWBoundedSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWBoundedSurface_swigregister(RWStepGeom_RWBoundedSurface)

class RWStepGeom_RWCartesianPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCartesianPoint_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCartesianPoint(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_CartesianPoint

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCartesianPoint_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_CartesianPoint

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCartesianPoint_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCartesianPoint

# Register RWStepGeom_RWCartesianPoint in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCartesianPoint_swigregister(RWStepGeom_RWCartesianPoint)

class RWStepGeom_RWCartesianTransformationOperator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCartesianTransformationOperator_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCartesianTransformationOperator(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_CartesianTransformationOperator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCartesianTransformationOperator_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_CartesianTransformationOperator
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCartesianTransformationOperator_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_CartesianTransformationOperator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCartesianTransformationOperator_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCartesianTransformationOperator

# Register RWStepGeom_RWCartesianTransformationOperator in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCartesianTransformationOperator_swigregister(RWStepGeom_RWCartesianTransformationOperator)

class RWStepGeom_RWCartesianTransformationOperator3d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCartesianTransformationOperator3d_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCartesianTransformationOperator3d(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_CartesianTransformationOperator3d

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCartesianTransformationOperator3d_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_CartesianTransformationOperator3d
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCartesianTransformationOperator3d_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_CartesianTransformationOperator3d

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCartesianTransformationOperator3d_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCartesianTransformationOperator3d

# Register RWStepGeom_RWCartesianTransformationOperator3d in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCartesianTransformationOperator3d_swigregister(RWStepGeom_RWCartesianTransformationOperator3d)

class RWStepGeom_RWCircle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCircle_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCircle(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Circle

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCircle_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Circle
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCircle_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Circle

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCircle_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCircle

# Register RWStepGeom_RWCircle in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCircle_swigregister(RWStepGeom_RWCircle)

class RWStepGeom_RWCompositeCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCompositeCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCompositeCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_CompositeCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCompositeCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_CompositeCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCompositeCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_CompositeCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCompositeCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCompositeCurve

# Register RWStepGeom_RWCompositeCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCompositeCurve_swigregister(RWStepGeom_RWCompositeCurve)

class RWStepGeom_RWCompositeCurveOnSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCompositeCurveOnSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCompositeCurveOnSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_CompositeCurveOnSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCompositeCurveOnSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_CompositeCurveOnSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCompositeCurveOnSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_CompositeCurveOnSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCompositeCurveOnSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCompositeCurveOnSurface

# Register RWStepGeom_RWCompositeCurveOnSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCompositeCurveOnSurface_swigregister(RWStepGeom_RWCompositeCurveOnSurface)

class RWStepGeom_RWCompositeCurveSegment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCompositeCurveSegment_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCompositeCurveSegment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_CompositeCurveSegment

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCompositeCurveSegment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_CompositeCurveSegment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCompositeCurveSegment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_CompositeCurveSegment

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCompositeCurveSegment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCompositeCurveSegment

# Register RWStepGeom_RWCompositeCurveSegment in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCompositeCurveSegment_swigregister(RWStepGeom_RWCompositeCurveSegment)

class RWStepGeom_RWConic(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWConic_swiginit(self, _RWStepGeom.new_RWStepGeom_RWConic(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Conic

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWConic_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Conic
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWConic_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Conic

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWConic_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWConic

# Register RWStepGeom_RWConic in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWConic_swigregister(RWStepGeom_RWConic)

class RWStepGeom_RWConicalSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWConicalSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWConicalSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_ConicalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWConicalSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_ConicalSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWConicalSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_ConicalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWConicalSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWConicalSurface

# Register RWStepGeom_RWConicalSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWConicalSurface_swigregister(RWStepGeom_RWConicalSurface)

class RWStepGeom_RWCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Curve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCurve_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Curve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCurve

# Register RWStepGeom_RWCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCurve_swigregister(RWStepGeom_RWCurve)

class RWStepGeom_RWCurveBoundedSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCurveBoundedSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCurveBoundedSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads curveboundedsurface.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_CurveBoundedSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCurveBoundedSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepGeom_CurveBoundedSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCurveBoundedSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes curveboundedsurface.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_CurveBoundedSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCurveBoundedSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCurveBoundedSurface

# Register RWStepGeom_RWCurveBoundedSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCurveBoundedSurface_swigregister(RWStepGeom_RWCurveBoundedSurface)

class RWStepGeom_RWCurveReplica(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCurveReplica_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCurveReplica(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_CurveReplica

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCurveReplica_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_CurveReplica
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCurveReplica_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_CurveReplica

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCurveReplica_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCurveReplica

# Register RWStepGeom_RWCurveReplica in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCurveReplica_swigregister(RWStepGeom_RWCurveReplica)

class RWStepGeom_RWCylindricalSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWCylindricalSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWCylindricalSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_CylindricalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCylindricalSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_CylindricalSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCylindricalSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_CylindricalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWCylindricalSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWCylindricalSurface

# Register RWStepGeom_RWCylindricalSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWCylindricalSurface_swigregister(RWStepGeom_RWCylindricalSurface)

class RWStepGeom_RWDegeneratePcurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWDegeneratePcurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWDegeneratePcurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_DegeneratePcurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWDegeneratePcurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_DegeneratePcurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWDegeneratePcurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_DegeneratePcurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWDegeneratePcurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWDegeneratePcurve

# Register RWStepGeom_RWDegeneratePcurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWDegeneratePcurve_swigregister(RWStepGeom_RWDegeneratePcurve)

class RWStepGeom_RWDegenerateToroidalSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWDegenerateToroidalSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWDegenerateToroidalSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_DegenerateToroidalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWDegenerateToroidalSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_DegenerateToroidalSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWDegenerateToroidalSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_DegenerateToroidalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWDegenerateToroidalSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWDegenerateToroidalSurface

# Register RWStepGeom_RWDegenerateToroidalSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWDegenerateToroidalSurface_swigregister(RWStepGeom_RWDegenerateToroidalSurface)

class RWStepGeom_RWDirection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWDirection_swiginit(self, _RWStepGeom.new_RWStepGeom_RWDirection(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Direction
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWDirection_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Direction

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWDirection_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Direction

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWDirection_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWDirection

# Register RWStepGeom_RWDirection in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWDirection_swigregister(RWStepGeom_RWDirection)

class RWStepGeom_RWElementarySurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWElementarySurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWElementarySurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_ElementarySurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWElementarySurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_ElementarySurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWElementarySurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_ElementarySurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWElementarySurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWElementarySurface

# Register RWStepGeom_RWElementarySurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWElementarySurface_swigregister(RWStepGeom_RWElementarySurface)

class RWStepGeom_RWEllipse(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWEllipse_swiginit(self, _RWStepGeom.new_RWStepGeom_RWEllipse(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Ellipse
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWEllipse_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Ellipse

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWEllipse_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Ellipse
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWEllipse_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Ellipse

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWEllipse_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWEllipse

# Register RWStepGeom_RWEllipse in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWEllipse_swigregister(RWStepGeom_RWEllipse)

class RWStepGeom_RWEvaluatedDegeneratePcurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWEvaluatedDegeneratePcurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWEvaluatedDegeneratePcurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_EvaluatedDegeneratePcurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWEvaluatedDegeneratePcurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_EvaluatedDegeneratePcurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWEvaluatedDegeneratePcurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_EvaluatedDegeneratePcurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWEvaluatedDegeneratePcurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWEvaluatedDegeneratePcurve

# Register RWStepGeom_RWEvaluatedDegeneratePcurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWEvaluatedDegeneratePcurve_swigregister(RWStepGeom_RWEvaluatedDegeneratePcurve)

class RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx_swiginit(self, _RWStepGeom.new_RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx

# Register RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx_swigregister(RWStepGeom_RWGeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx)

class RWStepGeom_RWGeometricRepresentationContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWGeometricRepresentationContext_swiginit(self, _RWStepGeom.new_RWStepGeom_RWGeometricRepresentationContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_GeometricRepresentationContext

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationContext_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_GeometricRepresentationContext

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWGeometricRepresentationContext

# Register RWStepGeom_RWGeometricRepresentationContext in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWGeometricRepresentationContext_swigregister(RWStepGeom_RWGeometricRepresentationContext)

class RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext_swiginit(self, _RWStepGeom.new_RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_GeometricRepresentationContextAndGlobalUnitAssignedContext

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_GeometricRepresentationContextAndGlobalUnitAssignedContext
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_GeometricRepresentationContextAndGlobalUnitAssignedContext

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext

# Register RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext_swigregister(RWStepGeom_RWGeometricRepresentationContextAndGlobalUnitAssignedContext)

class RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext_swiginit(self, _RWStepGeom.new_RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_GeometricRepresentationContextAndParametricRepresentationContext

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_GeometricRepresentationContextAndParametricRepresentationContext
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_GeometricRepresentationContextAndParametricRepresentationContext

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext

# Register RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext_swigregister(RWStepGeom_RWGeometricRepresentationContextAndParametricRepresentationContext)

class RWStepGeom_RWGeometricRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWGeometricRepresentationItem_swiginit(self, _RWStepGeom.new_RWStepGeom_RWGeometricRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_GeometricRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationItem_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_GeometricRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWGeometricRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWGeometricRepresentationItem

# Register RWStepGeom_RWGeometricRepresentationItem in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWGeometricRepresentationItem_swigregister(RWStepGeom_RWGeometricRepresentationItem)

class RWStepGeom_RWHyperbola(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWHyperbola_swiginit(self, _RWStepGeom.new_RWStepGeom_RWHyperbola(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Hyperbola

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWHyperbola_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Hyperbola
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWHyperbola_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Hyperbola

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWHyperbola_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWHyperbola

# Register RWStepGeom_RWHyperbola in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWHyperbola_swigregister(RWStepGeom_RWHyperbola)

class RWStepGeom_RWIntersectionCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWIntersectionCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWIntersectionCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_IntersectionCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWIntersectionCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_IntersectionCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWIntersectionCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_IntersectionCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWIntersectionCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWIntersectionCurve

# Register RWStepGeom_RWIntersectionCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWIntersectionCurve_swigregister(RWStepGeom_RWIntersectionCurve)

class RWStepGeom_RWLine(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWLine_swiginit(self, _RWStepGeom.new_RWStepGeom_RWLine(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Line

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWLine_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Line
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWLine_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Line

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWLine_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWLine

# Register RWStepGeom_RWLine in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWLine_swigregister(RWStepGeom_RWLine)

class RWStepGeom_RWOffsetCurve3d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWOffsetCurve3d_swiginit(self, _RWStepGeom.new_RWStepGeom_RWOffsetCurve3d(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_OffsetCurve3d

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOffsetCurve3d_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_OffsetCurve3d
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOffsetCurve3d_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_OffsetCurve3d

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOffsetCurve3d_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWOffsetCurve3d

# Register RWStepGeom_RWOffsetCurve3d in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWOffsetCurve3d_swigregister(RWStepGeom_RWOffsetCurve3d)

class RWStepGeom_RWOffsetSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWOffsetSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWOffsetSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_OffsetSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOffsetSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_OffsetSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOffsetSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_OffsetSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOffsetSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWOffsetSurface

# Register RWStepGeom_RWOffsetSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWOffsetSurface_swigregister(RWStepGeom_RWOffsetSurface)

class RWStepGeom_RWOrientedSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWOrientedSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWOrientedSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads orientedsurface.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_OrientedSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOrientedSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepGeom_OrientedSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOrientedSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes orientedsurface.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_OrientedSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOrientedSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWOrientedSurface

# Register RWStepGeom_RWOrientedSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWOrientedSurface_swigregister(RWStepGeom_RWOrientedSurface)

class RWStepGeom_RWOuterBoundaryCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWOuterBoundaryCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWOuterBoundaryCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_OuterBoundaryCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOuterBoundaryCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_OuterBoundaryCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOuterBoundaryCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_OuterBoundaryCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWOuterBoundaryCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWOuterBoundaryCurve

# Register RWStepGeom_RWOuterBoundaryCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWOuterBoundaryCurve_swigregister(RWStepGeom_RWOuterBoundaryCurve)

class RWStepGeom_RWParabola(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWParabola_swiginit(self, _RWStepGeom.new_RWStepGeom_RWParabola(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Parabola

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWParabola_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Parabola
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWParabola_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Parabola

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWParabola_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWParabola

# Register RWStepGeom_RWParabola in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWParabola_swigregister(RWStepGeom_RWParabola)

class RWStepGeom_RWPcurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWPcurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWPcurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Pcurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPcurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Pcurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPcurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Pcurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPcurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWPcurve

# Register RWStepGeom_RWPcurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWPcurve_swigregister(RWStepGeom_RWPcurve)

class RWStepGeom_RWPlacement(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWPlacement_swiginit(self, _RWStepGeom.new_RWStepGeom_RWPlacement(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Placement

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPlacement_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Placement
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPlacement_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Placement

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPlacement_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWPlacement

# Register RWStepGeom_RWPlacement in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWPlacement_swigregister(RWStepGeom_RWPlacement)

class RWStepGeom_RWPlane(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWPlane_swiginit(self, _RWStepGeom.new_RWStepGeom_RWPlane(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Plane

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPlane_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Plane
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPlane_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Plane

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPlane_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWPlane

# Register RWStepGeom_RWPlane in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWPlane_swigregister(RWStepGeom_RWPlane)

class RWStepGeom_RWPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWPoint_swiginit(self, _RWStepGeom.new_RWStepGeom_RWPoint(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Point

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPoint_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Point

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPoint_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWPoint

# Register RWStepGeom_RWPoint in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWPoint_swigregister(RWStepGeom_RWPoint)

class RWStepGeom_RWPointOnCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWPointOnCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWPointOnCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_PointOnCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPointOnCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_PointOnCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPointOnCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_PointOnCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPointOnCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWPointOnCurve

# Register RWStepGeom_RWPointOnCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWPointOnCurve_swigregister(RWStepGeom_RWPointOnCurve)

class RWStepGeom_RWPointOnSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWPointOnSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWPointOnSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_PointOnSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPointOnSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_PointOnSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPointOnSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_PointOnSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPointOnSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWPointOnSurface

# Register RWStepGeom_RWPointOnSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWPointOnSurface_swigregister(RWStepGeom_RWPointOnSurface)

class RWStepGeom_RWPointReplica(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWPointReplica_swiginit(self, _RWStepGeom.new_RWStepGeom_RWPointReplica(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_PointReplica

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPointReplica_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_PointReplica
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPointReplica_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_PointReplica

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPointReplica_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWPointReplica

# Register RWStepGeom_RWPointReplica in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWPointReplica_swigregister(RWStepGeom_RWPointReplica)

class RWStepGeom_RWPolyline(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWPolyline_swiginit(self, _RWStepGeom.new_RWStepGeom_RWPolyline(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Polyline

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPolyline_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Polyline
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPolyline_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Polyline

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWPolyline_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWPolyline

# Register RWStepGeom_RWPolyline in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWPolyline_swigregister(RWStepGeom_RWPolyline)

class RWStepGeom_RWQuasiUniformCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWQuasiUniformCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWQuasiUniformCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_QuasiUniformCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_QuasiUniformCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_QuasiUniformCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWQuasiUniformCurve

# Register RWStepGeom_RWQuasiUniformCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWQuasiUniformCurve_swigregister(RWStepGeom_RWQuasiUniformCurve)

class RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_QuasiUniformCurveAndRationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_QuasiUniformCurveAndRationalBSplineCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_QuasiUniformCurveAndRationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve

# Register RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve_swigregister(RWStepGeom_RWQuasiUniformCurveAndRationalBSplineCurve)

class RWStepGeom_RWQuasiUniformSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWQuasiUniformSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWQuasiUniformSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_QuasiUniformSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_QuasiUniformSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_QuasiUniformSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWQuasiUniformSurface

# Register RWStepGeom_RWQuasiUniformSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWQuasiUniformSurface_swigregister(RWStepGeom_RWQuasiUniformSurface)

class RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_QuasiUniformSurfaceAndRationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_QuasiUniformSurfaceAndRationalBSplineSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_QuasiUniformSurfaceAndRationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface

# Register RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface_swigregister(RWStepGeom_RWQuasiUniformSurfaceAndRationalBSplineSurface)

class RWStepGeom_RWRationalBSplineCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWRationalBSplineCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWRationalBSplineCurve(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_RationalBSplineCurve
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRationalBSplineCurve_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_RationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRationalBSplineCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_RationalBSplineCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRationalBSplineCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_RationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRationalBSplineCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWRationalBSplineCurve

# Register RWStepGeom_RWRationalBSplineCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWRationalBSplineCurve_swigregister(RWStepGeom_RWRationalBSplineCurve)

class RWStepGeom_RWRationalBSplineSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWRationalBSplineSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWRationalBSplineSurface(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_RationalBSplineSurface
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRationalBSplineSurface_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_RationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRationalBSplineSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_RationalBSplineSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRationalBSplineSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_RationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRationalBSplineSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWRationalBSplineSurface

# Register RWStepGeom_RWRationalBSplineSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWRationalBSplineSurface_swigregister(RWStepGeom_RWRationalBSplineSurface)

class RWStepGeom_RWRectangularCompositeSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWRectangularCompositeSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWRectangularCompositeSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_RectangularCompositeSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRectangularCompositeSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_RectangularCompositeSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRectangularCompositeSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_RectangularCompositeSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRectangularCompositeSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWRectangularCompositeSurface

# Register RWStepGeom_RWRectangularCompositeSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWRectangularCompositeSurface_swigregister(RWStepGeom_RWRectangularCompositeSurface)

class RWStepGeom_RWRectangularTrimmedSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWRectangularTrimmedSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWRectangularTrimmedSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_RectangularTrimmedSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRectangularTrimmedSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_RectangularTrimmedSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRectangularTrimmedSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_RectangularTrimmedSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWRectangularTrimmedSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWRectangularTrimmedSurface

# Register RWStepGeom_RWRectangularTrimmedSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWRectangularTrimmedSurface_swigregister(RWStepGeom_RWRectangularTrimmedSurface)

class RWStepGeom_RWReparametrisedCompositeCurveSegment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWReparametrisedCompositeCurveSegment_swiginit(self, _RWStepGeom.new_RWStepGeom_RWReparametrisedCompositeCurveSegment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_ReparametrisedCompositeCurveSegment

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWReparametrisedCompositeCurveSegment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_ReparametrisedCompositeCurveSegment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWReparametrisedCompositeCurveSegment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_ReparametrisedCompositeCurveSegment

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWReparametrisedCompositeCurveSegment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWReparametrisedCompositeCurveSegment

# Register RWStepGeom_RWReparametrisedCompositeCurveSegment in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWReparametrisedCompositeCurveSegment_swigregister(RWStepGeom_RWReparametrisedCompositeCurveSegment)

class RWStepGeom_RWSeamCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSeamCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSeamCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_SeamCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSeamCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_SeamCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSeamCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_SeamCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSeamCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSeamCurve

# Register RWStepGeom_RWSeamCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSeamCurve_swigregister(RWStepGeom_RWSeamCurve)

class RWStepGeom_RWSphericalSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSphericalSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSphericalSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_SphericalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSphericalSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_SphericalSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSphericalSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_SphericalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSphericalSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSphericalSurface

# Register RWStepGeom_RWSphericalSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSphericalSurface_swigregister(RWStepGeom_RWSphericalSurface)

class RWStepGeom_RWSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Surface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurface_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Surface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSurface

# Register RWStepGeom_RWSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSurface_swigregister(RWStepGeom_RWSurface)

class RWStepGeom_RWSurfaceCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSurfaceCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSurfaceCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_SurfaceCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_SurfaceCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_SurfaceCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSurfaceCurve

# Register RWStepGeom_RWSurfaceCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSurfaceCurve_swigregister(RWStepGeom_RWSurfaceCurve)

class RWStepGeom_RWSurfaceCurveAndBoundedCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSurfaceCurveAndBoundedCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSurfaceCurveAndBoundedCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_SurfaceCurveAndBoundedCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceCurveAndBoundedCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_SurfaceCurveAndBoundedCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceCurveAndBoundedCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_SurfaceCurveAndBoundedCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceCurveAndBoundedCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSurfaceCurveAndBoundedCurve

# Register RWStepGeom_RWSurfaceCurveAndBoundedCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSurfaceCurveAndBoundedCurve_swigregister(RWStepGeom_RWSurfaceCurveAndBoundedCurve)

class RWStepGeom_RWSurfaceOfLinearExtrusion(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSurfaceOfLinearExtrusion_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSurfaceOfLinearExtrusion(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_SurfaceOfLinearExtrusion

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceOfLinearExtrusion_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_SurfaceOfLinearExtrusion
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceOfLinearExtrusion_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_SurfaceOfLinearExtrusion

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceOfLinearExtrusion_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSurfaceOfLinearExtrusion

# Register RWStepGeom_RWSurfaceOfLinearExtrusion in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSurfaceOfLinearExtrusion_swigregister(RWStepGeom_RWSurfaceOfLinearExtrusion)

class RWStepGeom_RWSurfaceOfRevolution(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSurfaceOfRevolution_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSurfaceOfRevolution(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_SurfaceOfRevolution

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceOfRevolution_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_SurfaceOfRevolution
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceOfRevolution_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_SurfaceOfRevolution

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceOfRevolution_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSurfaceOfRevolution

# Register RWStepGeom_RWSurfaceOfRevolution in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSurfaceOfRevolution_swigregister(RWStepGeom_RWSurfaceOfRevolution)

class RWStepGeom_RWSurfacePatch(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSurfacePatch_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSurfacePatch(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_SurfacePatch

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfacePatch_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_SurfacePatch
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfacePatch_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_SurfacePatch

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfacePatch_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSurfacePatch

# Register RWStepGeom_RWSurfacePatch in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSurfacePatch_swigregister(RWStepGeom_RWSurfacePatch)

class RWStepGeom_RWSurfaceReplica(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSurfaceReplica_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSurfaceReplica(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_SurfaceReplica

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceReplica_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_SurfaceReplica
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceReplica_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_SurfaceReplica

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSurfaceReplica_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSurfaceReplica

# Register RWStepGeom_RWSurfaceReplica in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSurfaceReplica_swigregister(RWStepGeom_RWSurfaceReplica)

class RWStepGeom_RWSweptSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWSweptSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWSweptSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_SweptSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSweptSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_SweptSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSweptSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_SweptSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWSweptSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWSweptSurface

# Register RWStepGeom_RWSweptSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWSweptSurface_swigregister(RWStepGeom_RWSweptSurface)

class RWStepGeom_RWToroidalSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWToroidalSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWToroidalSurface(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_ToroidalSurface
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWToroidalSurface_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_ToroidalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWToroidalSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_ToroidalSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWToroidalSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_ToroidalSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWToroidalSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWToroidalSurface

# Register RWStepGeom_RWToroidalSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWToroidalSurface_swigregister(RWStepGeom_RWToroidalSurface)

class RWStepGeom_RWTrimmedCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWTrimmedCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWTrimmedCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_TrimmedCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWTrimmedCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_TrimmedCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWTrimmedCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_TrimmedCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWTrimmedCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWTrimmedCurve

# Register RWStepGeom_RWTrimmedCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWTrimmedCurve_swigregister(RWStepGeom_RWTrimmedCurve)

class RWStepGeom_RWUniformCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWUniformCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWUniformCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_UniformCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_UniformCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_UniformCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWUniformCurve

# Register RWStepGeom_RWUniformCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWUniformCurve_swigregister(RWStepGeom_RWUniformCurve)

class RWStepGeom_RWUniformCurveAndRationalBSplineCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWUniformCurveAndRationalBSplineCurve_swiginit(self, _RWStepGeom.new_RWStepGeom_RWUniformCurveAndRationalBSplineCurve(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_UniformCurveAndRationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformCurveAndRationalBSplineCurve_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_UniformCurveAndRationalBSplineCurve
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformCurveAndRationalBSplineCurve_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_UniformCurveAndRationalBSplineCurve

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformCurveAndRationalBSplineCurve_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWUniformCurveAndRationalBSplineCurve

# Register RWStepGeom_RWUniformCurveAndRationalBSplineCurve in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWUniformCurveAndRationalBSplineCurve_swigregister(RWStepGeom_RWUniformCurveAndRationalBSplineCurve)

class RWStepGeom_RWUniformSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWUniformSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWUniformSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_UniformSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_UniformSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_UniformSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWUniformSurface

# Register RWStepGeom_RWUniformSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWUniformSurface_swigregister(RWStepGeom_RWUniformSurface)

class RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface_swiginit(self, _RWStepGeom.new_RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_UniformSurfaceAndRationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_UniformSurfaceAndRationalBSplineSurface
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_UniformSurfaceAndRationalBSplineSurface

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface

# Register RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface_swigregister(RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface)

class RWStepGeom_RWVector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepGeom.RWStepGeom_RWVector_swiginit(self, _RWStepGeom.new_RWStepGeom_RWVector(*args))

    def Check(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Vector
        shares: Interface_ShareTool
        ach: Interface_Check

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWVector_Check(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepGeom_Vector

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWVector_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepGeom_Vector
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWVector_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepGeom_Vector

        Returns
        -------
        None

        """
        return _RWStepGeom.RWStepGeom_RWVector_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepGeom.delete_RWStepGeom_RWVector

# Register RWStepGeom_RWVector in _RWStepGeom:
_RWStepGeom.RWStepGeom_RWVector_swigregister(RWStepGeom_RWVector)





